#!/bin/sh

# atcwatch ist ein Paket mit relativen Imports: Start als Modul (-m atcwatch)
# mit dem Installationsroot (enthaelt atcwatch/ und venv/) im PYTHONPATH.
support_dir=$(CDPATH= cd "$(dirname "$0")/../../.." && pwd) || exit 1
PYTHONPATH="$support_dir" exec "$support_dir/venv/bin/python" -m atcwatch
